package com.hiramine.mychatapplication;

import android.support.v7.app.AppCompatActivity;
import android.os.Bundle;
import android.util.Log;
import android.view.View;
import android.widget.Button;
import android.widget.EditText;
import android.widget.TextView;
import android.widget.Toast;

import java.net.URISyntaxException;

import io.socket.client.IO;
import io.socket.client.Socket;
import io.socket.emitter.Emitter;

public class ChatClientActivity extends AppCompatActivity
{
	// 定数
	public static final  String EXTRA_NICKNAME = "NICKNAME";
	private static final String URI_SERVER     = "http://mychat1234.herokuapp.com/";

	// メンバー変数
	private String m_strNickname = "";
	private Socket m_socket;
	private EditText m_edittextMessage;

	@Override
	protected void onCreate( Bundle savedInstanceState )
	{
		super.onCreate( savedInstanceState );
		setContentView( R.layout.activity_chat_client );

		// 呼び出し元からパラメータ取得
		Bundle extras = getIntent().getExtras();
		if( null != extras )
		{
			m_strNickname = extras.getString( EXTRA_NICKNAME );
		}

		// ニックネームの表示
		TextView textviewNickname = (TextView)findViewById( R.id.textview_nickname );
		textviewNickname.setText( "Nickname : " + m_strNickname );

		// サーバーとの接続
		try
		{
			m_socket = IO.socket( URI_SERVER );
		}
		catch( URISyntaxException e )
		{    // IO.socket失敗
			e.printStackTrace();
			Toast.makeText( this, "URI is invalid.", Toast.LENGTH_SHORT ).show();
			finish();    // アクティビティ終了
			return;
		}
		m_socket.connect();    // 接続

		// 接続完了時の処理
		m_socket.on( Socket.EVENT_CONNECT, new Emitter.Listener()
		{
			@Override
			public void call( final Object... args )
			{
				runOnUiThread( new Runnable()
				{
					@Override
					public void run()
					{
						Toast.makeText( ChatClientActivity.this, "Connected.", Toast.LENGTH_SHORT ).show();
						// サーバーに、イベント名'join' でニックネームを送信
						m_socket.emit( "join", m_strNickname );
					}
				} );
			}
		} );

		// 接続エラー時の処理
		m_socket.on( Socket.EVENT_CONNECT_ERROR, new Emitter.Listener()
		{
			@Override
			public void call( final Object... args )
			{
				runOnUiThread( new Runnable()
				{
					@Override
					public void run()
					{
						Toast.makeText( ChatClientActivity.this, "Connection error.", Toast.LENGTH_SHORT ).show();
						finish();    // アクティビティ終了
						return;
					}
				} );
			}
		} );

		// 接続タイムアウト時の処理
		m_socket.on( Socket.EVENT_CONNECT_TIMEOUT, new Emitter.Listener()
		{
			@Override
			public void call( final Object... args )
			{
				runOnUiThread( new Runnable()
				{
					@Override
					public void run()
					{
						Toast.makeText( ChatClientActivity.this, "Connection timeout.", Toast.LENGTH_SHORT ).show();
						finish();    // アクティビティ終了
					}
				} );
			}
		} );

		// 切断時の処理
		m_socket.on( Socket.EVENT_DISCONNECT, new Emitter.Listener()
		{
			@Override
			public void call( final Object... args )
			{
				runOnUiThread( new Runnable()
				{
					@Override
					public void run()
					{
						Toast.makeText( ChatClientActivity.this, "Disconnected.", Toast.LENGTH_SHORT ).show();
					}
				} );
			}
		} );

		// 「Send」ボタンを押したときの処理
		m_edittextMessage = (EditText)findViewById( R.id.edittext_message );
		Button buttonSend = (Button)findViewById( R.id.button_send );
		buttonSend.setOnClickListener( new View.OnClickListener()
		{
			@Override
			public void onClick( View v )
			{
				String strMessage = m_edittextMessage.getText().toString();
				if( !strMessage.isEmpty() )
				{
					// サーバーに、イベント名'new message' で入力テキストを送信
					m_socket.emit( "new message", strMessage );

					m_edittextMessage.setText( "" );   // テキストボックスを空に。
				}
			}
		} );
	}

	@Override
	protected void onDestroy()
	{
		super.onDestroy();

		m_socket.disconnect();        // 切断
	}
}
